@@ -8,6 +8,19 @@ import napari
 # https://docs.github.com/ko/actions/learn-github-actions/variables
 pytestmark = pytest.mark.skipif(os.getenv('GITHUB_ACTIONS') == 'true', reason="NDViewer does not work in GitHub Actions")
 
+def test_timelapse_NDViewer(launch_mm_headless, setup_data_folder):
+    events = multi_d_acquisition_events(
+        num_time_points=10,
+        time_interval_s=0,
+    )
+
+    with Acquisition(setup_data_folder, 'acq', show_display=True) as acq:
+        acq.acquire(events)
+
+    # close viewer
+    acq.get_viewer().close()
+
+
 def test_multi_d_acq_NDViewer(launch_mm_headless, setup_data_folder):
     events = multi_d_acquisition_events(
         num_time_points=10,
@@ -27,6 +40,23 @@ def test_multi_d_acq_NDViewer(launch_mm_headless, setup_data_folder):
     acq.get_viewer().close()
 
 
+def test_timelapse_napari_viewer(launch_mm_headless, setup_data_folder):
+    events = multi_d_acquisition_events(
+        num_time_points=10,
+        time_interval_s=0,
+    )
+
+    viewer = napari.Viewer()
+
+    acq = Acquisition(setup_data_folder, 'acq', napari_viewer=viewer)
+    acq.acquire(events)
+    acq.mark_finished()
+
+    napari.run()
+    acq.get_dataset().close()
+    acq.await_completion()
+
+
 def test_multi_d_acq_napari_viewer(launch_mm_headless, setup_data_folder):
     events = multi_d_acquisition_events(
         num_time_points=10,
